@@ -1,8 +1,6 @@
-# $Id$
-#
 # BioPerl module for Bio::Factory::EMBOSS
 #
-# Please direct questions and support issues to <bioperl-l@bioperl.org> 
+# Please direct questions and support issues to <bioperl-l@bioperl.org>
 #
 # Cared for by Heikki Lehvaslaiho <heikki-at-bioperl-dot-org>
 #
@@ -18,28 +16,27 @@ Bio::Factory::EMBOSS - EMBOSS application factory class
 
 =head1 SYNOPSIS
 
-  # get an EMBOSS factory
+  # Get an EMBOSS factory
   use Bio::Factory::EMBOSS;
   $f = Bio::Factory::EMBOSS -> new();
-  # get an EMBOSS application  object from the factory
-  $water = $f->program('water');
+  # Get an EMBOSS application  object from the factory
+  $water = $f->program('water') || die "Program not found!\n";
+
+  # Here is an example of running the application - water can
+  # compare 1 sequence against 1 or more sequences using Smith-Waterman.
+  # Pass a Sequence object and a reference to an array of objects.
 
-  # here is an example of running the application -
-  # water can compare 1 sequence against 1 or more sequences
-  # in a database using Smith-Waterman
-  my $seq_to_test; # this would have a seq here
-  my @seqs_to_check; # this would be a list of seqs to compare 
-                       # (could be just 1)
   my $wateroutfile = 'out.water';
-  $water->run({-sequences => $seq_to_test,
-               -seqall    => \@seqs_to_check,
+  $water->run({-asequence => $seq_object,
+               -bsequence => \@seq_objects,
                -gapopen   => '10.0',
                -gapextend => '0.5',
                -outfile   => $wateroutfile});
-  # now you might want to get the alignment
+
+  # Now you might want to get the alignment
   use Bio::AlignIO;
   my $alnin = Bio::AlignIO->new(-format => 'emboss',
-		               	       -file   => $wateroutfile);
+                                -file   => $wateroutfile);
 
   while ( my $aln = $alnin->next_aln ) {
       # process the alignment -- these will be Bio::SimpleAlign objects
@@ -69,15 +66,15 @@ Bioperl mailing lists  Your participation is much appreciated.
   bioperl-l@bioperl.org                  - General discussion
   http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
-=head2 Support 
+=head2 Support
 
 Please direct usage questions or support issues to the mailing list:
 
 I<bioperl-l@bioperl.org>
 
-rather than to the module maintainer directly. Many experienced and 
-reponsive experts will be able look at the problem and quickly 
-address it. Please include a thorough description of the problem 
+rather than to the module maintainer directly. Many experienced and
+reponsive experts will be able look at the problem and quickly
+address it. Please include a thorough description of the problem
 with code and data examples if at all possible.
 
 =head2 Reporting Bugs
@@ -113,25 +110,24 @@ use Bio::Factory::ApplicationFactoryI;
 $EMBOSSVERSION = "2.0.0";
 
 sub new {
-  my($class,@args) = @_;
-  my $self = $class->SUPER::new(@args);
-  # set up defaults
+    my($class,@args) = @_;
+    my $self = $class->SUPER::new(@args);
+    # set up defaults
 
-  my($location) =
-      $self->_rearrange([qw(LOCATION )],
-			@args);
+    my($location) = $self->_rearrange([qw(LOCATION )], @args);
 
-  $self->{ '_programs' } = {};
-  $self->{ '_programgroup' } = {};
-  $self->{ '_groups' } = {};
+    $self->{ '_programs' } = {};
+    $self->{ '_programgroup' } = {};
+    $self->{ '_groups' } = {};
 
-  $self->location($location) if $location;
+    $self->location($location) if $location;
 
-  $self->_program_list; # retrieve info about available programs
+    $self->_program_list; # retrieve info about available programs
 
-  return $self;
+    return $self;
 }
 
+
 =head2 location
 
  Title   : location
@@ -139,24 +135,24 @@ sub new {
  Function: get/set the location of EMBOSS programs.
            Valid values are 'local' and 'novella'.
  Returns : string, defaults to 'local'
- Args    : string 
+ Args    : string
 
 =cut
 
 sub location {
     my ($self, $value) = @_;
     my %location = ('local' => '1',
-		    'novella' => '1'
-		    );
+                    'novella' => '1'
+                    );
     if (defined $value) {
-	$value = lc $value;
-	if ($location{$value}) {
-	    $self->{'_location'} = $value;
-	} else {
-	    $self->warn("Value [$value] not a valid value for ".
-			"location(). Defaulting to [local]");
-	    $self->{'_location'} = 'local';
-	}
+        $value = lc $value;
+        if ($location{$value}) {
+            $self->{'_location'} = $value;
+        } else {
+            $self->warn("Value [$value] not a valid value for ".
+                        "location(). Defaulting to [local]");
+            $self->{'_location'} = 'local';
+        }
     }
     $self->{'_location'} ||= 'local';
     return $self->{'_location'};
@@ -167,8 +163,9 @@ sub location {
 
  Title   : program
  Usage   : $embossfactory->program('program_name')
- Function: Creates a representation of a single EMBOSS program
- Returns : Bio::Tools::Run::EMBOSSApplication object
+ Function: Creates a representation of a single EMBOSS program and issues a
+           warning if the program was not found.
+ Returns : Bio::Tools::Run::EMBOSSApplication object or undef
  Args    : string, program name
 
 =cut
@@ -177,8 +174,8 @@ sub program {
     my ($self, $value) = @_;
 
     unless( $self->{'_programs'}->{$value} ) {
-	$self->warn("Application [$value] is not available!");
-	return undef;
+        $self->warn("Application [$value] is not available!");
+        return undef;
     }
     my $attr = {};
     $attr->{name} = $value;
@@ -188,6 +185,7 @@ sub program {
     return $appl;
 }
 
+
 =head2 version
 
  Title   : $self->version
@@ -201,17 +199,13 @@ sub program {
 
 sub version {
     my ($self) = @_;
-    my ($version);
-    eval {
-	$version = `embossversion -auto`;
-    };
-    $self->throw("EMBOSS suite of programs is not available \n\n$@")
-	if $@;
+    my $version = `embossversion -auto`;
+    $self->throw("EMBOSS suite of programs is not available") if $?;
     chop $version;
 
     # compare versions
     $self->throw("EMBOSS has to be at least version $EMBOSSVERSION got $version\n")
-	if $version lt  $EMBOSSVERSION;
+        if $version lt $EMBOSSVERSION;
 
     return $version;
 }
@@ -257,24 +251,25 @@ sub _program_list {
     my ($self) = @_;
     if( $^O =~ /Mac/i ) { return; }
     {
-	local * SAVERR;
-	open SAVERR, ">&STDERR";
-	open STDERR, ">/dev/null";
-	open(WOSSOUT, "wossname -auto |") || return;
-	open STDERR, ">&SAVERR";
+        my $null = ($^O =~ m/mswin/i) ? 'NUL' : '/dev/null';
+        local * SAVERR;
+        open SAVERR, ">&STDERR";
+        open STDERR, ">$null";
+        open(WOSSOUT, "wossname -auto |") || return;
+        open STDERR, ">&SAVERR";
 
     }
     local $/ = "\n\n";
-    while(<WOSSOUT> ) {	
-	my ($groupname) = (/^([A-Z][A-Z0-9 ]+)$/m);
-	#print $groupname, "\n" if $groupname;
-	$self->{'_groups'}->{$groupname} = [] if $groupname;
-	while ( /^([a-z]\w+) +(.+)$/mg ) {
-	    #print "$1\t$2 \n" if $1;
-	    $self->{'_programs'}->{$1} = $2 if $1; 
-	    $self->{'_programgroup'}->{$1} = $groupname if $1;
-	    push @{$self->{'_groups'}->{$groupname}}, $1 if $1;
-	}
+    while(<WOSSOUT> ) {
+        my ($groupname) = (/^([A-Z][A-Z0-9 ]+)$/m);
+        #print $groupname, "\n" if $groupname;
+        $self->{'_groups'}->{$groupname} = [] if $groupname;
+        while ( /^([a-z]\w+) +(.+)$/mg ) {
+            #print "$1\t$2 \n" if $1;
+            $self->{'_programs'}->{$1} = $2 if $1;
+            $self->{'_programgroup'}->{$1} = $groupname if $1;
+            push @{$self->{'_groups'}->{$groupname}}, $1 if $1;
+        }
     }
     close(WOSSOUT);
 
