@@ -1,3 +1,4 @@
+#
 # BioPerl module for Bio::Tools::Run::Alignment::Amap
 #
 # Please direct questions and support issues to <bioperl-l@bioperl.org> 
@@ -461,8 +462,9 @@ sub _setparams {
     #FIXME: This may be only for *nixes. Double check in other OSes
     $param_string .= " > ".$self->outfile_name;
     
-    if ($self->verbose < 0) { 
-	$param_string .= ' 2> /dev/null';
+    if ($self->verbose < 0) {
+	my $null = ($^O =~ m/mswin/i) ? 'NUL' : '/dev/null';
+	$param_string .= " 2> $null";
     }
     return $param_string;
 }
