@@ -1,4 +1,3 @@
-# $Id: MCS.pm,v 1.3 2007/05/25 10:14:55 sendu Exp $
 #
 # BioPerl module for Bio::Tools::Run::MCS
 #
@@ -216,7 +215,7 @@ sub new {
            third argument represents annotation of the exons in the alignment.
 
            The alignment can be provided as a multi-fasta format alignment
-           filename, or a Bio::Align::AlignI complient object (eg. a
+           filename, or a Bio::Align::AlignI compliant object (eg. a
            Bio::SimpleAlign).
 
            The position in the genome can be provided as a Bio::Location::Atomic
@@ -325,7 +324,8 @@ sub _setparams {
                                            -switches => \@SWITCHES,
                                            -dash => 1);
     
-    $param_string .= ' 1>/dev/null' if $self->quiet;
+    my $null = ($^O =~ m/mswin/i) ? 'NUL' : '/dev/null';
+    $param_string .= " 1>$null" if $self->quiet;
     
     return $param_string;
 }
