@@ -1,4 +1,4 @@
-# $Id$
+#
 # BioPerl module for Bio::Tools::Run::Phylo::LVB
 #
 # Created by Daniel Barker, based on ProtPars.pm by Shawn Hoon 
@@ -335,7 +335,8 @@ sub _run {
     chdir($self->tempdir);
     #open a pipe to run lvb to bypass interactive menus
     if ($self->quiet() || $self->verbose() < 0) {
-    	open(LVB_PIPE,"|".$self->executable.">/dev/null");
+	my $null = ($^O =~ m/mswin/i) ? 'NUL' : '/dev/null';
+    	open(LVB_PIPE,"|".$self->executable.">$null");
     }
     else {
     	open(LVB_PIPE,"|".$self->executable);
