@@ -97,7 +97,7 @@ this is still experimental as v3.6 is still under alpha release and not all func
 
 Title		: TYPE 
 Description	: (optional)
-             Only avaliable in phylip v3.6
+             Only available in phylip v3.6
 
                   This program supports 3 types of consensus generation 
 
@@ -388,7 +388,8 @@ sub _run {
     chdir($self->tempdir);
     # open a pipe to run Consense to bypass interactive menus
     if ($self->quiet() || $self->verbose() < 0) {
-   	open(Consense,"| ".$self->executable .">/dev/null");
+	my $null = ($^O =~ m/mswin/i) ? 'NUL' : '/dev/null';
+   	open(Consense,"| ".$self->executable .">$null");
     }
     else {
     	open(Consense,"| ".$self->executable);
